@@ -50,9 +50,7 @@ class CatBoostAlgorithm(BaseAlgorithm):
         self.learner_params = {
             "learning_rate": self.params.get("learning_rate", 0.1),
             "depth": self.params.get("depth", 3),
-            "min_data_in_leaf": self.params.get("min_data_in_leaf", 1),
             "rsm": self.params.get("rsm", 1.0),
-            "subsample": self.params.get("subsample", 1.0),
             "random_seed": self.params.get("seed", 1),
             "loss_function": loss_function,
         }
@@ -62,7 +60,6 @@ class CatBoostAlgorithm(BaseAlgorithm):
             learning_rate=self.learner_params["learning_rate"],
             depth=self.learner_params["depth"],
             rsm=self.learner_params["rsm"],
-            min_data_in_leaf=self.learner_params["min_data_in_leaf"],
             loss_function=self.learner_params["loss_function"],
             verbose=False,
             allow_writing_files=False,
@@ -189,8 +186,6 @@ classification_params = {
     "learning_rate": [0.05, 0.1, 0.2],
     "depth": [2, 3, 4, 5, 6],
     "rsm": [0.7, 0.8, 0.9, 1],  # random subspace method
-    "subsample": [0.7, 0.8, 0.9, 1],  # random subspace method
-    "min_data_in_leaf": [1, 5, 10, 15, 20, 30, 50],
     "loss_function": ["Logloss"],
 }
 
@@ -198,8 +193,6 @@ classification_default_params = {
     "learning_rate": 0.1,
     "depth": 6,
     "rsm": 0.9,
-    "subsample": 1.0,
-    "min_data_in_leaf": 15,
     "loss_function": "Logloss",
 }
 
@@ -256,8 +249,6 @@ regression_default_params = {
     "learning_rate": 0.1,
     "depth": 6,
     "rsm": 0.9,
-    "subsample": 1.0,
-    "min_data_in_leaf": 15,
     "loss_function": "RMSE",
 }
 
